@@ -11,8 +11,7 @@ import cv2
 
 
 _font = r'tl2_lib/data/sans-serif.ttf'
-if not os.path.isfile(_font):
-  _font = None
+
 
 def pil_resize(img_pil, size=()):
   """
@@ -188,7 +187,10 @@ def add_text(img,
              clone=False):
   if clone:
     img = copy.deepcopy(img)
-  font = ImageFont.truetype(font=_font, size=size)
+  if not os.path.isfile(_font):
+    font = None
+  else:
+    font = ImageFont.truetype(font=_font, size=size)
   draw = ImageDraw.Draw(img)
   draw.text(xy=xy, text=text, fill=color, font=font)
   return img
@@ -211,7 +213,10 @@ def add_text_in_tensor(img_tensor,
   img_tensor = torchvision.utils.make_grid(img_tensor.cpu(), nrow=1, padding=0, normalize=True)
   img_pil = tv_trans_f.to_pil_image(img_tensor)
 
-  font = ImageFont.truetype(font=_font, size=size)
+  if not os.path.isfile(_font):
+    font = None
+  else:
+    font = ImageFont.truetype(font=_font, size=size)
   draw = ImageDraw.Draw(img_pil)
   draw.text(xy=xy, text=text, fill=color, font=font)
 
@@ -375,7 +380,10 @@ class Testing_pil_utils(unittest.TestCase):
     img_path = "template_lib/datasets/images/zebra_GT_target_origin.png"
 
     source_img = Image.open(img_path)
-    font = ImageFont.truetype(_font)
+    if not os.path.isfile(_font):
+      font = None
+    else:
+      font = ImageFont.truetype(_font)
     text = "very loooooooooooooooooong text"
 
     # get text size
